@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,7 +23,7 @@ public:
     Q_REQUIRED_RESULT QString formatSummary(TreeNode *node) const override;
 
 private:
-    DefaultCombinedViewFormatter();
+    DefaultCombinedViewFormatter() = delete;
     GrantleeViewFormatter *mGrantleeViewFormatter = nullptr;
 };
 }
